@@ -30,6 +30,7 @@ DATA_SUBJECT = "data_subject"
 DATA_USE = "data_use"
 DATASET = "dataset"
 DELETE = "delete"
+PRIVACY_REQUEST_REDACTION_PATTERNS = "privacy-request-redaction-patterns"
 ENCRYPTION = "encryption"
 MESSAGING_TEMPLATE = "messaging-template"
 EVALUATION = "evaluation"
@@ -51,6 +52,7 @@ PRIVACY_REQUEST_ACCESS_RESULTS = "privacy-request-access-results"
 PRIVACY_REQUEST_EMAIL_INTEGRATIONS = "privacy-request-email-integrations"
 PRIVACY_REQUEST_NOTIFICATIONS = "privacy-request-notifications"
 READ = "read"
+READ_OWN = "read-own"
 REGISTER = "register"
 RESET = "reset"
 RESPOND = "respond"
@@ -133,6 +135,11 @@ DATA_USE_UPDATE = f"{DATA_USE}:{UPDATE}"
 DATA_USE_DELETE = f"{DATA_USE}:{DELETE}"
 
 DATASET_CREATE_OR_UPDATE = f"{DATASET}:{CREATE_OR_UPDATE}"
+
+PRIVACY_REQUEST_REDACTION_PATTERNS_READ = f"{PRIVACY_REQUEST_REDACTION_PATTERNS}:{READ}"
+PRIVACY_REQUEST_REDACTION_PATTERNS_UPDATE = (
+    f"{PRIVACY_REQUEST_REDACTION_PATTERNS}:{UPDATE}"
+)
 DATASET_DELETE = f"{DATASET}:{DELETE}"
 DATASET_READ = f"{DATASET}:{READ}"
 DATASET_TEST = f"{DATASET}:{TEST}"
@@ -226,6 +233,7 @@ TAXONOMY_DELETE = f"{TAXONOMY}:{DELETE}"
 USER_CREATE = f"{USER}:{CREATE}"
 USER_DELETE = f"{USER}:{DELETE}"
 USER_READ = f"{USER}:{READ}"
+USER_READ_OWN = f"{USER}:{READ_OWN}"
 USER_UPDATE = f"{USER}:{UPDATE}"
 USER_PASSWORD_RESET = f"{USER}:{PASSWORD_RESET}"
 
@@ -286,6 +294,8 @@ SCOPE_DOCS = {
     DATA_USE_UPDATE: "Update data uses",
     DATASET_CREATE_OR_UPDATE: "Create or modify datasets",
     DATASET_DELETE: "Delete datasets",
+    PRIVACY_REQUEST_REDACTION_PATTERNS_READ: "View privacy request redaction patterns",
+    PRIVACY_REQUEST_REDACTION_PATTERNS_UPDATE: "Update privacy request redaction patterns",
     DATASET_READ: "View datasets",
     DATASET_TEST: "Run a standalone privacy request test for a dataset",
     ENCRYPTION_EXEC: "Encrypt data",
@@ -354,6 +364,7 @@ SCOPE_DOCS = {
     USER_UPDATE: "Update users",
     USER_DELETE: "Remove users",
     USER_READ: "View users",
+    USER_READ_OWN: "View own user",
     USER_PASSWORD_RESET: "Reset another user's password",
     USER_PERMISSION_CREATE: "Create user permissions",
     USER_PERMISSION_UPDATE: "Update user permissions",
